@@ -30,7 +30,7 @@ returns a :class:`.protocol.Request` object with a
 :attr:`.protocol.Request.response` future (which is a :class:`.Message` again).
 
 On the server side, a resource tree gets built from
-:class:`aiocoap.resource.CoAPResource` objects into a
+:class:`aiocoap.resource.Resource` objects into a
 :class:`aiocoap.resource.Site`, which is assigned to the context at creation
 time.
 """
